==> spip_4.0.4.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Hizivaat pep urls',

	// B
	'bouton_supprimer_url' => 'Dilemel an URL-mañ',

	// E
	'erreur_arbo_2_segments_max' => 'Ne c’hallit ket implij ouzhpenn daou lod an URL evit un dra',

	// I
	'icone_configurer_urls' => 'Kefluniañ an URLs',
	'icone_controler_urls' => 'URLs sklaer',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Tra',

	// L
	'label_tri_date' => 'Deiziad',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'URL nevez',
	'label_urls_activer_controle_oui' => 'Gweredekaat merañ araokaet an URLs',
	'label_urls_nb_max_car' => 'Niverenn uc’hek an arouezennoù',
	'label_urls_nb_min_car' => 'Niverenn izek an arouezennoù',
	'liberer_url' => 'Diac’hubiñ',
	'liste_des_urls' => 'Pep URLs',

	// T
	'texte_type_urls' => 'Gallout a rit dibab amañ dindan an doare ma vo jedet chomlec’h ar pajennoù.',
	'texte_type_urls_attention' => 'Diwallit, ne’z aio an dra-mañ en-dro nemet ma vez staliet mat ar restr @htaccess@ e gwrizienn al lec’hienn.',
	'titre_gestion_des_urls' => 'Merañ an URLs',
	'titre_type_arbo' => 'URLs Gwezek',
	'titre_type_html' => 'URLs Traoù HTML',
	'titre_type_libres' => 'URLs dieub',
	'titre_type_page' => 'URLs Pajenn',
	'titre_type_propres' => 'URLs Prop',
	'titre_type_propres2' => 'URLs Prop+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URLs Prop e query-string',
	'titre_type_simple' => 'URLs Simples

URLs Eeun',
	'titre_type_standard' => 'URLs Roll-istor',
	'titre_type_urls' => 'Seurt chomlec’hioù URL',
	'tout_voir' => 'Gwelout pep URLs',

	// U
	'url_ajoutee' => 'Ouzhpennet eo bet an URL',

	// V
	'verrouiller_url' => 'Prennañ'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// A
	'actualiser_toutes' => 'Hizivaat pep urls',

	// B
	'bouton_supprimer_url' => 'Dilemel an URL-mañ',

	// E
	'erreur_arbo_2_segments_max' => 'Ne c’hallit ket implij ouzhpenn daou lod an URL evit un dra',

	// I
	'icone_configurer_urls' => 'Kefluniañ an URLs',
	'icone_controler_urls' => 'URLs sklaer',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URLs',
	'info_objet' => 'Tra',

	// L
	'label_tri_date' => 'Deiziad',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'URL nevez',
	'label_urls_activer_controle_oui' => 'Gweredekaat merañ araokaet an URLs',
	'label_urls_nb_max_car' => 'Niverenn uc’hek an arouezennoù',
	'label_urls_nb_min_car' => 'Niverenn izek an arouezennoù',
	'liberer_url' => 'Diac’hubiñ',
	'liste_des_urls' => 'Pep URLs',

	// T
	'texte_type_urls' => 'Gallout a rit dibab amañ dindan an doare ma vo jedet chomlec’h ar pajennoù.',
	'texte_type_urls_attention' => 'Diwallit, ne’z aio an dra-mañ en-dro nemet ma vez staliet mat ar restr @htaccess@ e gwrizienn al lec’hienn.',
	'titre_gestion_des_urls' => 'Merañ an URLs',
	'titre_type_arbo' => 'URLs Gwezek',
	'titre_type_html' => 'URLs Traoù HTML',
	'titre_type_libres' => 'URLs dieub',
	'titre_type_page' => 'URLs Pajenn',
	'titre_type_propres' => 'URLs Prop',
	'titre_type_propres2' => 'URLs Prop+<tt>.html</tt>',
	'titre_type_propres_qs' => 'URLs Prop e query-string',
	'titre_type_simple' => 'URLs Simples

URLs Eeun',
	'titre_type_standard' => 'URLs Roll-istor',
	'titre_type_urls' => 'Seurt chomlec’hioù URL',
	'tout_voir' => 'Gwelout pep URLs',

	// U
	'url_ajoutee' => 'Ouzhpennet eo bet an URL',

	// V
	'verrouiller_url' => 'Prennañ',
];
